##  IT Component
  * Identify IT components that make up infrastructure elements, such as hardware or microservices. Distinguish them from applications and note their technical relationships.
  * Extract IT components with their product specifications and identify which applications they support or belong to.
  * Identify technical components that underpin applications (e.g., 'Microsoft SharePoint 2019' supporting SharePoint applications). Note platform affiliations.
